==> gnat-ajis-for-gnatbench-2.5.1-src.tgz: gnat-ajis-6.5.0w-src/prototypes/ada2java/runtime/java/com/adacore/ajis/internal/ada/AdaAccess.java <==
//////////////////////////////////////////////////////////////////////////////
//                                                                          //
//                                  AJIS                                    //
//                                                                          //
//                     Copyright (C) 2007-2008, AdaCore                     //
//                                                                          //
// GNAT is free software;  you can  redistribute it  and/or modify it under //
// terms of the  GNU General Public License as published  by the Free Soft- //
// ware  Foundation;  either version 2,  or (at your option) any later ver- //
// sion.  GNAT is distributed in the hope that it will be useful, but WITH- //
// OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY //
// or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License //
// for  more details.  You should have  received  a copy of the GNU General //
// Public License  distributed with GNAT;  see file COPYING.  If not, write //
// to  the  Free Software Foundation,  51  Franklin  Street,  Fifth  Floor, //
// Boston, MA 02110-1301, USA.                                              //
//                                                                          //
// As a special exception,  if other files  instantiate  generics from this //
// unit, or you link  this unit with other files  to produce an executable, //
// this  unit  does not  by itself cause  the resulting  executable  to  be //
// covered  by the  GNU  General  Public  License.  This exception does not //
// however invalidate  any other reasons why  the executable file  might be //
// covered by the  GNU Public License.                                      //
//                                                                          //
//////////////////////////////////////////////////////////////////////////////

package com.adacore.ajis.internal.ada;

import com.adacore.ajis.AJISLibrary;

public class AdaAccess {
	
	public int [] fAcc;
	
	public static int [] simpleNullAccess;	
	public static int [] fatNullAccess;
	
	public AdaAccess (int [] acc) {
		fAcc = acc;
	}
	
	public int [] getAccess () {
		return fAcc;
	}
	
	public static boolean isNull (int [] addr) {
		for (int j = 0; j < addr.length; ++j) {
			if (addr [j] != 0) {
				return false;
			}
		}
		
		return true;
	}
		
	private static native int [] getSimpleNullAccess ();
	private static native int [] getFatNullAccess ();
	
	static {
		AJISLibrary.load ();	
		simpleNullAccess = getSimpleNullAccess();
		fatNullAccess = getFatNullAccess();		
	}
}

==> gnat-ajis-for-gnatbench-2.6.0-src.tgz: gnat-ajis-7.0.0w-src/prototypes/ada2java/runtime/java/com/adacore/ajis/internal/ada/AdaAccess.java <==
//////////////////////////////////////////////////////////////////////////////
//                                                                          //
//                                  AJIS                                    //
//                                                                          //
//                     Copyright (C) 2007-2011, AdaCore                     //
//                                                                          //
// GNAT is free software;  you can  redistribute it  and/or modify it under //
// terms of the  GNU General Public License as published  by the Free Soft- //
// ware  Foundation;  either version 2,  or (at your option) any later ver- //
// sion.  GNAT is distributed in the hope that it will be useful, but WITH- //
// OUT ANY WARRANTY;  without even the  implied warranty of MERCHANTABILITY //
// or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License //
// for  more details.  You should have  received  a copy of the GNU General //
// Public License  distributed with GNAT;  see file COPYING.  If not, write //
// to  the  Free Software Foundation,  51  Franklin  Street,  Fifth  Floor, //
// Boston, MA 02110-1301, USA.                                              //
//                                                                          //
// As a special exception,  if other files  instantiate  generics from this //
// unit, or you link  this unit with other files  to produce an executable, //
// this  unit  does not  by itself cause  the resulting  executable  to  be //
// covered  by the  GNU  General  Public  License.  This exception does not //
// however invalidate  any other reasons why  the executable file  might be //
// covered by the  GNU Public License.                                      //
//                                                                          //
//////////////////////////////////////////////////////////////////////////////

package com.adacore.ajis.internal.ada;

public class AdaAccess {
	
	public int [] fAcc;
	
	private static int [] simpleNullAccess = null;
	
	public static int [] simpleNullAccess () {
		if (simpleNullAccess == null) {
			simpleNullAccess = getSimpleNullAccess ();
		}
		
		return simpleNullAccess;
	}
	
	public AdaAccess (int [] acc) {
		fAcc = acc;
	}
	
	public int [] getAccess () {
		return fAcc;
	}
	
	public static boolean isNull (int [] addr) {
		for (int j = 0; j < addr.length; ++j) {
			if (addr [j] != 0) {
				return false;
			}
		}
		
		return true;
	}
		
	private static native int [] getSimpleNullAccess ();	
}
